Welcome to MoleCool's documentation!
====================================

``MoleCool`` is a Python library for numerical modeling of *light-matter interactions*, 
specializing in **laser cooling of molecules**.
It is designed for researchers and physicists working with **atomic and molecular systems**,
from simple few-level models and diatomics to polyatomics and even radioactive species.

More details and citing this package: |arxiv_badge|

Current version: |version|

.. grid:: 1 2 2 2
   :gutter: 3 3 3 4


   .. grid-item-card:: :material-regular:`download;2em` Installation
      :link: installation
      :link-type: doc
      :class-card: sd-text-center sd-shadow

      Instructions on how to install ``MoleCool`` on your system.
      +++

      .. button-ref:: installation
         :color: primary
         :expand:

         To the Installation Guide
         
   .. grid-item-card:: :material-regular:`menu_book;2em` User Guide
      :link: user_guide/introduction
      :link-type: doc
      :class-card: sd-text-center sd-shadow
      
      Learn how to get started and explore its main features.
      +++

      .. button-ref:: user_guide/introduction
         :color: success
         :expand:

         To the User Guide

   .. grid-item-card:: :material-regular:`science;2em` Examples
      :link: auto_examples/core/index
      :link-type: doc
      :class-card: sd-text-center sd-shadow

      Browse examples and tutorials to apply the features to different level systems.
      +++
      
      .. button-ref:: auto_examples/core/index
         :color: secondary
         :expand:

         To the Examples

   .. grid-item-card:: :material-regular:`api;2em` API Reference
      :link: api
      :link-type: doc
      :class-card: sd-text-center sd-shadow
      
      Full API documentation with all modules, classes, and functions.
      +++

      .. button-ref:: api
         :color: light
         :expand:

         To the API Reference

.. seealso::
   
   For having a look on the source code in the GitHub repository:

   .. button-link:: https://github.com/LangenGroup/MoleCool/
      :color: secondary
      :outline:
    
      :fab:`github` GitHub

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Contents:

   installation
   user_guide/index
   examples
   api

-------------------------

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. include:: substitutions.rst
